@@ -193,7 +193,8 @@ impl BasicMacro {
     /// $include(path)
     fn include(args: &str, greedy: bool, processor: &mut Processor) -> Result<String, RadError> {
         if let Some(args) = ArgParser::args_with_len(args, 1, greedy) {
-            let file_path = std::path::Path::new(&args[0]);
+            let raw = Utils::trim(&args[0])?;
+            let file_path = std::path::Path::new(&raw);
             Ok(processor.from_file(file_path, true)?)
         } else {
             Err(RadError::InvalidArgument("Include requires an argument"))
@@ -283,7 +284,7 @@ impl BasicMacro {
     /// This return string true or false
     fn ifdef(args: &str, greedy: bool, processor: &mut Processor) -> Result<String, RadError> {
         if let Some(args) = ArgParser::args_with_len(args, 1, greedy) {
-            let name = &args[0];
+            let name = &Utils::trim(&args[0])?;
             let map = processor.get_map();
 
             // Return true or false by the definition
@@ -300,7 +301,7 @@ impl BasicMacro {
     /// $undef(macro_name)
     fn undefine_call(args: &str, greedy: bool, processor: &mut Processor) -> Result<String, RadError> {
         if let Some(args) = ArgParser::args_with_len(args, 1, greedy) {
-            let name = &args[0];
+            let name = &Utils::trim(&args[0])?;
 
             processor.map.undefine(name);
             Ok("".to_owned())
@@ -311,14 +312,15 @@ impl BasicMacro {
 
     // $foreach()
     // $foreach(\*a,b,c*\,$:)
-    fn foreach(args: &str, greedy: bool, _: &mut Processor) -> Result<String, RadError> {
+    fn foreach(args: &str, greedy: bool, processor: &mut Processor) -> Result<String, RadError> {
         if let Some(args) = ArgParser::args_with_len(args, 2, greedy) {
             let mut sums = String::new();
             let target = &args[1]; // evaluate on loop
             let loopable = &args[0];
 
             for value in loopable.split(',') {
-                sums.push_str(&ITER.replace_all(target, value));
+                let result = processor.parse_chunk(0, &MAIN_CALLER.to_owned(), &ITER.replace_all(target, value))?;
+                sums.push_str(&result);
             }
             Ok(sums)
         } else {
@@ -327,7 +329,7 @@ impl BasicMacro {
     }
 
     // $forloop(1,5,$:)
-    fn forloop(args: &str, greedy: bool, _: &mut Processor) -> Result<String, RadError> {
+    fn forloop(args: &str, greedy: bool, processor: &mut Processor) -> Result<String, RadError> {
         if let Some(args) = ArgParser::args_with_len(args, 3, greedy) {
             let mut sums = String::new();
             let expression = &args[2]; // evaluate on loop
@@ -342,7 +344,8 @@ impl BasicMacro {
             } else { return Err(RadError::InvalidArgument("Forloop's min value should be non zero positive integer")); }
 
             for value in min..=max {
-                sums.push_str(&ITER.replace_all(expression, &value.to_string()));
+                let result = processor.parse_chunk(0, &MAIN_CALLER.to_owned(), &ITER.replace_all(expression, &value.to_string()))?;
+                sums.push_str(&result);
             }
 
             Ok(sums)
@@ -393,10 +396,10 @@ impl BasicMacro {
 
     fn merge_path(args: &str, greedy: bool, _: &mut Processor) -> Result<String, RadError> {
         if let Some(args) = ArgParser::args_with_len(args, 2, greedy) {
-            let target = &args[0];
-            let added = &args[1];
+            let target = Utils::trim(&args[0])?;
+            let added = Utils::trim(&args[1])?;
 
-            let out = format!("{}",&std::path::Path::new(target).join(added).display());
+            let out = format!("{}",&std::path::Path::new(&target).join(&added).display());
             Ok(out)
         } else {
             Err(RadError::InvalidArgument("Path macro needs two arguments"))
